# Code for Deploying the SAP LeanIX GitHub Agent
### On this page
  * [Sample Code](https://help.sap.com/docs/leanix/ea/code-for-deploying-sap-leanix-github-agent#sample-code)
  * [Environment Variables](https://help.sap.com/docs/leanix/ea/code-for-deploying-sap-leanix-github-agent#environment-variables)


Sample docker-compose code and environment variables.
